@@ -78,7 +78,7 @@ class DormitoryApplicantStudent(Base):
     """
     __tablename__ = 'univer_dormitory_applicant_students'
 
-    applicant_id = Column(ForeignKey('univer_dormitory_applicant.dormitory_applicant_id'), primary_key=True)
+    applicant_id = Column('dormitory_applicant_id', ForeignKey('univer_dormitory_applicant.dormitory_applicant_id'), primary_key=True)
     applicant = relationship('DormitoryApplicant')  # Заявление общежития
     student_id = Column(ForeignKey('univer_students.students_id'), primary_key=True)
     student = relationship('Student')  # Студент
@@ -107,7 +107,7 @@ class StudentDormitoryRoomLink(Base):
     dormitory_room = relationship('DormitoryRoom')  # Комната общежития
     year = Column(Integer)  # Год
     created_at = Column('created', DateTime)  # Дата и время создания
-    applicant_id = Column(ForeignKey('univer_dormitory_applicant.dormitory_applicant_id'))
+    applicant_id = Column('dormitory_applicant_id', ForeignKey('univer_dormitory_applicant.dormitory_applicant_id'))
     applicant = relationship('DormitoryApplicant')  # Заявления общежития
 
     def __repr__(self):
@@ -130,9 +130,9 @@ class StudentDormitoryRoomSettleHistory(Base):
     date = Column('history_date', DateTime)  # Дата и время
     user_id = Column(ForeignKey('univer_users.user_id'))
     user = relationship('User')  # Пользователь
-    personnel_id = Column(ForeignKey('univer_personal.personal_id'))
+    personnel_id = Column('personal_id', ForeignKey('univer_personal.personal_id'))
     personnel = relationship('Personnel')  # Сотрудник
-    applicant_id = Column(ForeignKey('univer_dormitory_applicant.dormitory_applicant_id'))
+    applicant_id = Column('dormitory_applicant_id', ForeignKey('univer_dormitory_applicant.dormitory_applicant_id'))
     applicant = relationship('DormitoryApplicant')  # Заявления общежития
     dormitory_id = Column(ForeignKey('platonus_univer_dormitories.dormitoryID'))
     dormitory = relationship('Dormitory')  # Общежитие
